package com.sf.system.deployment.mapper;

import com.sf.system.deployment.domain.DeploymentWhitelistInfo;
import com.sf.system.deployment.domain.DeploymentWhitelistList;

import java.util.List;

/**
 * 白名单列表Mapper接口
 * 
 * @author ztzh
 * @date 2024-05-06
 */
public interface DeploymentWhitelistInfoMapper 
{
    /**
     * 查询白名单列表
     * 
     * @param id 白名单列表主键
     * @return 白名单列表
     */
    public DeploymentWhitelistInfo selectDeploymentWhitelistInfoById(Long id);

    /**
     * 查询白名单列表列表
     * 
     * @param deploymentWhitelistInfo 白名单列表
     * @return 白名单列表集合
     */
    public List<DeploymentWhitelistInfo> selectDeploymentWhitelistInfoList(DeploymentWhitelistInfo deploymentWhitelistInfo);

    /**
     * 新增白名单列表
     * 
     * @param deploymentWhitelistInfo 白名单列表
     * @return 结果
     */
    public int insertDeploymentWhitelistInfo(DeploymentWhitelistInfo deploymentWhitelistInfo);

    /**
     * 修改白名单列表
     * 
     * @param deploymentWhitelistInfo 白名单列表
     * @return 结果
     */
    public int updateDeploymentWhitelistInfo(DeploymentWhitelistInfo deploymentWhitelistInfo);

    /**
     * 删除白名单列表
     * 
     * @param id 白名单列表主键
     * @return 结果
     */
    public int deleteDeploymentWhitelistInfoById(Long id);


    /**
     * 批量删除白名单列表
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDeploymentWhitelistInfoByIds(Long[] ids);

    /**
     * 批量删除白名单成员列
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDeploymentWhitelistListByWhitelistIds(Long[] ids);
    
    /**
     * 批量新增白名单成员列
     * 
     * @param deploymentWhitelistListList 白名单成员列列表
     * @return 结果
     */
    public int batchDeploymentWhitelistList(List<DeploymentWhitelistList> deploymentWhitelistListList);
    

    /**
     * 通过白名单列表主键删除白名单成员列信息
     * 
     * @param id 白名单列表ID
     * @return 结果
     */
    public int deleteDeploymentWhitelistListByWhitelistId(Long id);
}
